diff scripts/plot/replot.m @ 5251:454e3c98300d

[project @ 2005-03-28 16:05:51 by jwe]
author jwe
date Mon, 28 Mar 2005 16:05:51 +0000
parents eecc24b92d97
children 4c8a2e4e0717
line wrap: on
line diff
--- a/scripts/plot/replot.m	Fri Feb 01 21:27:04 2008 -0500
+++ b/scripts/plot/replot.m	Mon Mar 28 16:05:51 2005 +0000
@@ -27,9 +27,9 @@
 function replot ()
 
   if (nargin == 0)
-    ## No semicolon following the __greplot__ line unless you also fix
-    ## gplot.l to allow it.
-    __greplot__
+    ## No semicolon following the __gnuplot_replot__ line unless you
+    ## also fix gplot.l to allow it.
+    __gnuplot_replot__
   else
     usage ("replot ()");
   endif